@@ -180,7 +180,9 @@ SettingsDialog::SettingsDialog(QWidget *parent, int activeTab) : QDialog(parent)
           << (QStringList() << tr("Small")       << "Small")
           << (QStringList() << tr("Medium")      << "Medium")
           << (QStringList() << tr("Large")       << "Large")
-          << (QStringList() << tr("Extra Large") << "Extra Large");
+          << (QStringList() << tr("Extra Large") << "Extra Large")
+          << (QStringList() << tr("Super")       << "Super");
+
 
     if (SETTINGS.value("Other/downloadinfo", "").toString() == "true")
         populateTableAndListTab(true);
@@ -697,7 +699,6 @@ void SettingsDialog::populateAvailable(bool downloadItems) {
                   << "Genre"
                   << "Publisher"
                   << "Developer"
-                  << "Rating"
                   << "Game Cover";
 
         labelOptions << "Game Title"
@@ -709,8 +710,7 @@ void SettingsDialog::populateAvailable(bool downloadItems) {
                     << "ESRB"
                     << "Genre"
                     << "Publisher"
-                    << "Developer"
-                    << "Rating";
+                    << "Developer";
     }
 
     available.sort();
