@@ -41,7 +41,7 @@ const QString AppNameLower      = "mupen64plus-qt";
 const QString ParentName        = "Mupen64Plus";
 const QString ParentNameLower   = "mupen64plus";
 
-const QString Description = QObject::tr("A basic launcher for <ParentName> using Qt.").replace("<ParentName>",ParentName);
+const QString Description = QObject::tr("A customizable launcher for <ParentName> using Qt.").replace("<ParentName>",ParentName);
 const QString Copyright = "";
 const QString Website = "<a href=\"http://www.mupen64plus.org/\">"
         + QObject::tr("<ParentName> website").replace("<ParentName>",ParentName)
@@ -50,6 +50,8 @@ const QString GitHub = "<a href=\"https://github.com/dh4/mupen64plus-qt\">"
         + QObject::tr("GitHub repository")
         + "</a>";
 
+const QString TheGamesDBAPIKey = "5dd59a89da5c0018b0e9ded34e299cf675e94d51e229a19822074d1a67019f9f";
+
 #ifdef Q_OS_WIN
     #define SETTINGS    QSettings(AppNameLower+".ini", QSettings::IniFormat)
 #else
